==> haskell-validation-selective-0.2.0.0-129-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-validation-selective.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 validation-selective
version:              0.2.0.0
visibility:           public
id:                   validation-selective-0.2.0.0-4oq5uZqJfSY1VrVSIEbNkg
key:                  validation-selective-0.2.0.0-4oq5uZqJfSY1VrVSIEbNkg
license:              MPL-2.0
copyright:            2020-2023 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Dmitrii Kovanikov, Veronika Romashkina
homepage:             https://github.com/kowainik/validation-selective
synopsis:
    Lighweight pure data validation based on Applicative and Selective functors

description:
    Lighweight pure data validation based on Applicative and Selective
    functors. The library builds validation interface around the
    following data type:

    @
    __data__ Validation e a
    \    = Failure e
    \    | Success a
    @

category:             Validation, Selective, Data
abi:                  390ed3b46956b456d4c4eba102e723f8
exposed:              True
exposed-modules:      Validation Validation.Combinators
import-dirs:          /usr/lib/ghc-9.6.6/site-local/validation-selective-0.2.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/validation-selective-0.2.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/validation-selective-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-validation-selective
hs-libraries:         HSvalidation-selective-0.2.0.0-4oq5uZqJfSY1VrVSIEbNkg
depends:
    base-4.18.2.1 deepseq-1.4.8.1
    selective-0.7.0.1-KJqeAWzDI1REI5jNmdpKJ6

haddock-interfaces:
    /usr/share/doc/haskell-validation-selective/html/validation-selective.haddock

haddock-html:         /usr/share/doc/haskell-validation-selective/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-validation-selective-0.2.0.0-130-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-validation-selective.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 validation-selective
version:              0.2.0.0
visibility:           public
id:                   validation-selective-0.2.0.0-FXSBl0yIg6vJRB1BPPmBxC
key:                  validation-selective-0.2.0.0-FXSBl0yIg6vJRB1BPPmBxC
license:              MPL-2.0
copyright:            2020-2023 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Dmitrii Kovanikov, Veronika Romashkina
homepage:             https://github.com/kowainik/validation-selective
synopsis:
    Lighweight pure data validation based on Applicative and Selective functors

description:
    Lighweight pure data validation based on Applicative and Selective
    functors. The library builds validation interface around the
    following data type:

    @
    __data__ Validation e a
    \    = Failure e
    \    | Success a
    @

category:             Validation, Selective, Data
abi:                  88cf6eb36ce30b6d6a9edb120e5a4361
exposed:              True
exposed-modules:      Validation Validation.Combinators
import-dirs:          /usr/lib/ghc-9.6.6/site-local/validation-selective-0.2.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/validation-selective-0.2.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/validation-selective-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-validation-selective
hs-libraries:         HSvalidation-selective-0.2.0.0-FXSBl0yIg6vJRB1BPPmBxC
depends:
    base-4.18.2.1 deepseq-1.4.8.1
    selective-0.7.0.1-8XCz7YxnwcY8F6KY55moJ0

haddock-interfaces:
    /usr/share/doc/haskell-validation-selective/html/validation-selective.haddock

haddock-html:         /usr/share/doc/haskell-validation-selective/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
